@@ -67,7 +67,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
   layout2->addRow(tr("Current day back:"), cdayback);
 
   layout3->addRow(tr("Widget background:"), widgetback);
-  layout3->addRow(tr("Transparence:"), transparence);
+  layout3->addRow(tr("Transparency:"), transparence);
   layout3->addRow(tr("Day names language:"), lang);
 
   QPushButton *save = new QPushButton("&Save");
